// ===========================================================================
// CONTENT  : CLASS StringSpy
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 10/04/2004
// HISTORY  :
//  26/06/2000  mdu  CREATED
//	10/04/2004	mdu  changed	-->	addAllElements()
//
// Copyright (c) 2000-20024, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.joi.inspectors;

// ===========================================================================
// IMPORTS
// ===========================================================================
import org.pfsw.joi.AbstractObjectSpy;
import org.pfsw.joi.ArrayElementSpy;
import org.pfsw.joi.ElementSpy;

/**
 * Instances of this class are responsible to provide the internal state
 * of strings for presentation in an inspector.
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
public class StringSpy extends AbstractObjectSpy
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================

  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public StringSpy(Object obj) throws SecurityException
  {
    super(obj);
  } // StringSpy()

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================

  /**
   * Returns the wrapped String (is doing the type cast).
   */
  protected String getString()
  {
    return ((String)this.getObject());
  } // getString()

  // --------------------------------------------------------------------------

  @Override
  protected void addAllElements() throws SecurityException
  {
    ElementSpy elementSpy = null;
    String str = null;
    int index = 0;

    str = this.getString();
    while (index < str.length())
    {
      elementSpy = new ArrayElementSpy(this, index, new Character(str.charAt(index)), Character.TYPE);
      this.getElementHolders().add(elementSpy);
      index++;
    }
  } // addAllElements()

  // --------------------------------------------------------------------------

  /**
   * Returns whether or not the elements
   * of the underlying object can be sorted.
   */
  @Override
  protected boolean canBeSorted()
  {
    return false;
  } // canBeSorted()

  // --------------------------------------------------------------------------

} // class StringSpy